# Creative Commons Markdown

[![npm](https://flat.badgen.net/npm/license/cc-md)](https://www.npmjs.org/package/cc-md)
[![npm](https://flat.badgen.net/npm/v/cc-md)](https://www.npmjs.org/package/cc-md)
[![CI](https://img.shields.io/github/workflow/status/idleberg/Creative-Commons-Markdown/CI?style=flat-square)](https://github.com/idleberg/Creative-Commons-Markdown/actions)


On November 25th, 2013, [Creative Commons](http://creativecommons.org/) announced their next generation licenses: [Creative Commons 4.0](https://creativecommons.org/weblog/entry/40768). By default, these are available as [HTML](http://creativecommons.org/licenses/) or [plaintext](http://creativecommons.org/weblog/entry/41127). This project adds [Markdown](http://daringfireball.net/projects/markdown/)-formatted licenses to that list, while aiming for best [compatibility on GitHub](https://github.github.com/gfm/).

## Licenses

* `BY` – [Attribution](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/by.markdown)
* `BY-NC` – [Attribution-NonCommercial](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/by-nc.markdown)
* `BY-NC-ND` – [Attribution-NonCommercial-NoDerivatives](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/by-nc-nd.markdown)
* `BY-NC-SA` – [Attribution-NonCommercial-ShareAlike](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/by-nc-sa.markdown)
* `BY-ND` – [Attribution-NoDerivatives](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/by-nd.markdown)
* `BY-SA` – [Attribution-ShareAlike](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/by-sa.markdown)
* `CC0` – [CC0](https://github.com/idleberg/Creative-Commons-Markdown/blob/master/4.0/zero.markdown)

## File extension

There's a plethora of Markdown file extensions, but I have decided to go with `markdown`. Read why:

> *"We no longer live in a 8.3 world, so we should be using the most descriptive file extensions. It’s sad that all our operating systems rely on this stupid convention instead of the better creator code or a metadata model, but great that they now support longer file extensions."*  
>
> – Hilton Lipschitz ([via](http://hiltmon.com/blog/2012/03/07/the-markdown-file-extension/))

> *"…the only file extension I would endorse is “.markdown”, for the same reason offered by Hilton Lipschitz"*
>
> – John Gruber, creator of Markdown ([via](http://daringfireball.net/linked/2014/01/08/markdown-extension))

## Usage

There are other ways to get the licenses than downloading the [latest release](https://github.com/idleberg/Creative-Commons-Markdown/releases/latest) in your browser:

```bash
# Use git
$ git clone https://github.com/idleberg/Creative-Commons-Markdown cc-md

# npm
$ npm install cc-md
```

## Contribute

If you notice any mistakes in content or formatting, please send a pull request with your correction.
